@@ -16,9 +16,8 @@ class AudioUnitIO;
 class AudioInputAudioUnit : public AudioInput{
 
 public:
-	AudioInputAudioUnit(std::string deviceID);
+	AudioInputAudioUnit(std::string deviceID, AudioUnitIO* io);
 	virtual ~AudioInputAudioUnit();
-	virtual void Configure(uint32_t sampleRate, uint32_t bitsPerSample, uint32_t channels);
 	virtual void Start();
 	virtual void Stop();
 	void HandleBufferCallback(AudioBufferList* ioData);
