@@ -12,7 +12,15 @@
 namespace tgvoip {
 class DarwinSpecific{
 public:
+	enum{
+		THREAD_PRIO_USER_INTERACTIVE,
+		THREAD_PRIO_USER_INITIATED,
+		THREAD_PRIO_UTILITY,
+		THREAD_PRIO_BACKGROUND,
+		THREAD_PRIO_DEFAULT
+	};
 	static void GetSystemName(char* buf, size_t len);
+	static void SetCurrentThreadPriority(int priority);
 };
 }
 
